Module renderer

Module renderer 

Modules

graphics
shaders

Structs

DividerRenderInfo
Information needed to render a pane divider
PaneDividerSettings
Settings for rendering pane dividers and focus indicators
PaneRenderInfo
Information needed to render a single pane
PaneTitleInfo
Information needed to render a pane title bar
Renderer
Renderer for the terminal using custom wgpu cell renderer

Functions

compute_visible_separator_marks
Compute which separator marks are visible in the current viewport.

Type Aliases

SeparatorMark
Visible command separator mark: (row, col_offset, optional_color)