Modules
Structs
- Divider
Render Info - Information needed to render a pane divider
- Pane
Divider Settings - Settings for rendering pane dividers and focus indicators
- Pane
Render Info - Information needed to render a single pane
- Pane
Title Info - Information needed to render a pane title bar
- Renderer
- Renderer for the terminal using custom wgpu cell renderer
Functions
- compute_
visible_ separator_ marks - Compute which separator marks are visible in the current viewport.
Type Aliases
- Separator
Mark - Visible command separator mark: (row, col_offset, optional_color)