Shader management for the renderer.
Manages two independent shader renderers:
- Background shader (
custom_shader_renderer) — full-screen post-processing effect rendered before the terminal cell grid, compatible with Ghostty/Shadertoy GLSL. - Cursor shader (
cursor_shader_renderer) — cursor overlay effect rendered after the cell grid, enabling glow, trail, and other cursor effects.
Sub-modules
- [
background] — init andimpl Renderermethods for the background shader - [
cursor] — init andimpl Renderermethods for the cursor shader - [
shared] —impl Renderermethods that update both renderers (mouse, cursor state, etc.)
Structs
- Cursor
Shader Init Params - Parameters for initialising the cursor shader renderer.
- Custom
Shader Enable Params - Parameters for enabling/updating the background custom shader at runtime.
- Custom
Shader Init Params - Parameters for initialising the background custom shader renderer.